<?php
namespace ChangeList\Controllers;

use App\Controllers\Controller;

use App\Helpers;
use App\Models\Setting;

use Slim\Views\Twig as View;
use Illuminate\Database\Capsule\Manager as DB;
use ChangeList\Models\ChangeListItem;
use ChangeList\Models\ChangeListGroupItem;

class ChangeListAdminController extends Controller
{   
    public $responseArray = array();
    public $tempGroupItem;

    public function renderPage($request, $response, $args) {
        return $this->view->render($response, 'changelistsettingsapp.twig');
    }
    public function newChangeItem($request, $response, $args) {
        $params = $request->getParams();

        // print_r($params);

        
        $item = ChangeListItem::create(
            [
                'type'=>$params['type'],
                'icon'=>$params['icon'],
                'description'=>$params['description'],
                'groupId'=>$params['groupId'],
                'isShow'=>1,
            ],
        );
        return $response->withJSON(['status'=>'success', 'id' => $item->id, "icon" => $item->icon]);
    }

    public function newChangeGroupItem($request, $response, $args) {
        $params = $request->getParams();
        $item = ChangeListGroupItem::create(
            [
                'name'=>$params['name'],
                'createDate'=>$params['createDate'],
                'isShow'=>1,
                'serverId' => $params['server'],
            ],
        );
        
        return $response->withJSON(['status'=>'success', 'id' => $item->id]);
    }
    public function updateChangeItem($request, $response, $args) {
        $params = $request->getParams();
        $item = ChangeListItem::where('id','=', $params['id'])->update(
            [
                'type'=>$params['type'],
                'icon'=>$params['icon'],
                'description'=>$params['description'],
                'isShow'=>1,
            ],
        );
        // $item = ChangeListItem::updateOrCreate(['id'=>$params['id']],['description'=>$params['description']],['groupId'=>$params['groupId']],['icon'=>$params['icon']]);
        return $response->withJSON(['status'=>'success', 'id' => $params['id']]);
    }

    public function updateChangeGroupItem($request, $response, $args) {
        $params = $request->getParams();
        $changeListGroupItem = ChangeListGroupItem::where('id', '=', $params['id'])->update([
            'name'=>$params['name'],
            'createDate'=>$params['createDate'],
        ]);
        
        return $response->withJSON(['status'=>'success', 'id' => $params['id']]); // sadece id donmesi de gerekiyor arkadas 
    }

    public function deleteChangeItem($request, $response, $args) {
        $params = $request->getParams();
        $item = ChangeListItem::where('id','=', $params['id'])->update(
            [
                'isShow'=>0,
            ],
        );
        return $response->withJSON(['status'=>'success', 'id' => $params['id']]);
    }
    
    public function deleteChangeGroupItem($request, $response, $args) {
        $params = $request->getParams();
        $item = ChangeListGroupItem::where('id','=', $params['id'])->update(
            [
                'isShow'=>0,
            ],
        );
        return $response->withJSON(['status'=>'success', 'id' => $params['id']]);
        
    }

    public function getChangeListAll($req, $res, $args) {
        // 'changeList' : [
        //     {
        //         'id': '0', 'name': '256th ChangeList', 
        //         'items': [
        //             { 'id': '1', 'description': 'hadi bakalım hayırlısı arkadas ne cıkacak karsımıza', 'icon':'icon deneme bir iki uc'}
        //         ]
        //     }
        // ]
        
        // sayfalama yapılması gerek 
        $groupItems = ChangeListGroupItem::where('isShow', 1)->get();
        $responseArray = array();
        
        
        $groupItems->each(function($item) {

            $this->tempGroupItem = (object)[];
            $this->tempGroupItem->id = $item->id;
            $this->tempGroupItem->name = $item->name;
            $this->tempGroupItem->childs = array();
            
            $listItems = ChangeListItem::where('groupId', $item->id)->where('isShow', true)->orderBy('type')->get();
            
            $listItems->each(function($listItem) {
                $tempChild = (object) ['id' => $listItem->id, 'description' => $listItem->description, 'icon' => $listItem->icon];
                array_push($this->tempGroupItem->childs, $tempChild);
            });
            
            array_push($this->responseArray, $this->tempGroupItem);
        });

        return $res->withJSON(['status' => 'success', 'changeList' => $this->responseArray]);
    }


    public function setupdb($req, $res) {
        if ($this->auth->isAdmin()) {
            $migrationsPath = __DIR__ . "/../../database/migrations";
            if(file_exists("$migrationsPath/schema.sql")) {
                $sql = file_get_contents("$migrationsPath/schema.sql");
                DB::statement($sql);
            }
            return $res->withJSON(['status' => 'setup success']);
        }
        return $res->withJSON(['status' => 'failure', 'msg'=> 'Permission Denied !!']); 
    }
    public function updatedb($req, $res) {
        if ($this->auth->isAdmin()) {
            $migrationsPath = __DIR__ . "/../../database/migrations";
            if(file_exists("$migrationsPath/schema-update.sql")) {
                $sql = file_get_contents("$migrationsPath/schema-update.sql");
                DB::statement($sql);
            }
            return $res->withJSON(['status' => 'changeList table field updated..']);
        }
        return $res->withJSON(['status' => 'failure', 'msg'=> 'Permission Denied !!']); 
    }
    
    public function dropChangeListTables($req, $res) {
        if ($this->auth->isAdmin()) {
            $migrationsPath = __DIR__ . "/../../database/migrations";
            if(file_exists("$migrationsPath/schema-drop-tables.sql")) {
                $sql = file_get_contents("$migrationsPath/schema-drop-tables.sql");
                DB::statement($sql);
            }
            return $res->withJSON(['status' => 'changeList tables dropped !..']);
        }
        return $res->withJSON(['status' => 'failure', 'msg'=> 'Permission Denied !!']); 
    }
}
